import { Component, inject } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import { Group } from '../../shared/models/group';
import { Policy } from '../../shared/models/policy';
import { MatExpansionModule } from '@angular/material/expansion';
import { PoliciesModule } from '../../policies/policies.module';
import { MatInputModule } from '@angular/material/input';
import { MatFormFieldModule } from '@angular/material/form-field';
import { ReactiveFormsModule } from '@angular/forms';
import { MatButtonModule } from '@angular/material/button';
import { MatIconModule } from '@angular/material/icon';
import { PolicyTableComponent } from "../../policies/policy-table/policy-table.component";
import { PolicyAddButtonComponent } from '../../policies/policy-add-button/policy-add-button.component';
import { HermesClientService } from '../../hermes-client.service';
import { GroupChatter } from '../../shared/models/group-chatter';

@Component({
  selector: 'group-page',
  imports: [
    MatButtonModule,
    MatExpansionModule,
    MatFormFieldModule,
    MatIconModule,
    MatInputModule,
    PoliciesModule,
    PolicyAddButtonComponent,
    ReactiveFormsModule,
    PolicyTableComponent
  ],
  templateUrl: './group-page.component.html',
  styleUrl: './group-page.component.scss'
})
export class GroupPageComponent {
  private readonly _router = inject(Router);
  private readonly _route = inject(ActivatedRoute);
  private readonly _client = inject(HermesClientService);
  private _group: Group | undefined;
  private _chatters: GroupChatter[];
  private _policies: Policy[];

  groups: Group[] = [];

  constructor() {
    this._chatters = [];
    this._policies = [];

    this._route.params.subscribe((p: any) => {
      const group_id = p.id;

      this._route.data.subscribe(async (data: any) => {
        this.groups = [...data['groups']];
        const group = this.groups.find((g: Group) => g.id == group_id);

        if (!group) {
          await this._router.navigate(['groups']);
          return;
        }

        this._group = group;
        this._chatters = [...data['chatters'].filter((c: GroupChatter) => c.group_id == group_id)];
        this._policies = [...data['policies'].filter((p: Policy) => p.group_id == group_id)];
      });
    });
  }

  get group() {
    return this._group;
  }

  get chatters() {
    return this._chatters;
  }

  get policies() {
    return this._policies;
  }

  delete() {
    if (!this.group)
      return;

    this._client.first(d => d.d.request.type == 'delete_group' && d.d.request.data.id == this.group!.id)
      .subscribe(async () => await this._router.navigate(['groups']));
    this._client.deleteGroup(this.group.id);
  }
}